@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 # vim:se tw=0 sts=4 ts=4 et ai:
 """
-Copyright © 2014 Osamu Aoki
+Copyright © 2014-2015 Osamu Aoki
 
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the
@@ -43,9 +43,11 @@ import debmake.untar
 # Basic package information
 #######################################################################
 
+__debian_policy__   = '3.9.6'   # debian policy version
+__debian_compat__   = '9'       # debian/comapt
 __programname__     = 'debmake'
-__version__         = '4.1.7'
-__copyright__       = 'Copyright © 2014 Osamu Aoki <osamu@debian.org>'
+__version__         = '4.2.2'
+__copyright__       = 'Copyright © 2014-2015 Osamu Aoki <osamu@debian.org>'
 __license__         = '''\
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
@@ -66,11 +68,6 @@ TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 '''
 
-__debian_policy__   = '3.9.5'   # debian policy version
-__debian_compat__   = '9'       # debhelper compatibility level in 
-                                # debian/comapt
-                                # Adjust this to 8 or less if 
-                                # backporting to pre-wheezy
 
 #######################################################################
 # main program
@@ -79,8 +76,8 @@ def main():
 #######################################################################
 # set parameters from commandline etc.
 #######################################################################
-    debmake.debug.debug('D: {} started'.format(sys.argv[0]))
-    debmake.debug.debug('D: PYTHONPATH = {} '.format(':'.join(sys.path)))
+    debmake.debug.debug('D: {} started'.format(sys.argv[0]), type='i')
+    debmake.debug.debug('D: PYTHONPATH = {} '.format(':'.join(sys.path)), type='i')
     print('I: set parameters', file=sys.stderr)
     para = {}
     para['cwd'] = os.getcwd()
@@ -123,14 +120,14 @@ def main():
         print('I: scan source for copyright+license text and file extensions', file=sys.stderr)
         (nonlink_files, xml_html_files, binary_files, huge_files, counter, count_list) = debmake.scanfiles.scanfiles()
         data = debmake.copyright.check_copyright(nonlink_files, mode=para['copyright'])
-        print(debmake.copyright.copyright('package', set(), data, xml_html_files, binary_files, huge_files, mode=para['copyright']))
+        print(debmake.copyright.copyright('package', set(), data, xml_html_files, binary_files, huge_files, mode=para['copyright'], tutorial=para['tutorial']))
         return
 #######################################################################
 # -k: compare debian/copyright with the source and exit
 #######################################################################
     if para['kludge'] !=0:
         print('I: compare debian/copyright with the source', file=sys.stderr)
-        debmake.kludge.kludge(para['kludge'])
+        debmake.kludge.kludge(para['kludge'], para['pedantic'])
         return
 #######################################################################
 # sanity check parameters without digging deep into source tree
