@@ -139,9 +139,14 @@ def analyze(para):
     if len(para['debs']) != 1 and len(para['dev']) != len(para['lib']):
         print('E: # of "dev":{} != # of "lib": {}.'.format(len(para['dev']), len(para['lib'])), file=sys.stderr)
         exit(1)
-    if len(para['dbg']) != 0 and len(para['dbg']) != (len(para['bin']) + len(para['lib'])):
-        print('E: # of "dbg":{} != # of "bin+lib": {}.'.format(len(para['dev']), len(para['bin']) + len(para['lib'])), file=sys.stderr)
-        exit(1)
+    if len(para['dbg']) == 1:
+        if (len(para['bin']) + len(para['lib'])) == 0:
+            print('E: # of "dbg":{} but # of "bin+lib": {}.'.format(len(para['dbg']), len(para['bin']) + len(para['lib'])), file=sys.stderr)
+            exit(1)
+    elif len(para['dbg']) > 1:
+        if len(para['dbg']) != (len(para['bin']) + len(para['lib'])):
+            print('E: # of "dbg":{} != # of "bin+lib": {}.'.format(len(para['dbg']), len(para['bin']) + len(para['lib'])), file=sys.stderr)
+            exit(1)
     if para['lib'] != []:
         setmultiarch = True
     elif para['bin'] != [] and len(para['debs']) == 1:
@@ -174,17 +179,19 @@ def analyze(para):
                 exit(1)
         elif deb['type'] == 'dbg':
             para['override'].update({'dbg'})
-            pkg = masterdbg(deb['package'])
             pkgs = para['bin'] + para['lib']
-            if pkg in pkgs:
-                para['debs'][i]['depends'].update({pkg + ' (= ${binary:Version})'})
-            else:
-                print('E: {} does not match package in "{}".'.format(deb['package'], ', '.join(para['bin'] + para['lib'])), file=sys.stderr)
-                exit(1)
-            pkgs.remove(pkg)
-            if pkgs == []:        
+            if len(para['dbg']) == 1:
+                for pkg in pkgs:
+                    para['debs'][i]['depends'].update({pkg + ' (= ${binary:Version})'})
                 para['dh_strip'] += '\tdh_strip --dbg-package={}\n'.format(deb['package'])
             else:
+                pkg = masterdbg(deb['package'])
+                if pkg in pkgs:
+                    para['debs'][i]['depends'].update({pkg + ' (= ${binary:Version})'})
+                else:
+                    print('E: {} does not match package in "{}".'.format(deb['package'], ', '.join(pkgs)), file=sys.stderr)
+                    exit(1)
+                pkgs.remove(pkg)
                 para['dh_strip'] += '\tdh_strip -X{} --dbg-package={}\n'.format(' -X'.join(pkgs), deb['package'])
         elif deb['type'] == 'perl':
             for libpkg in para['lib']:
@@ -233,6 +240,7 @@ def analyze(para):
         para['dh_with'].update({'autoreconf'})
         para['build_type']      = 'Autotools with autoreconf'
         para['build_depends'].update({'dh-autoreconf'})
+        para['export'].update({'autotools'})
         if os.path.isfile('autogen.sh'):
             para['override'].update({'autogen'})
         else:
@@ -243,6 +251,7 @@ def analyze(para):
         para['dh_with'].update({'autoreconf'})
         para['build_type']      = 'Autotools with autoreconf (old)'
         para['build_depends'].update({'dh-autoreconf'})
+        para['export'].update({'autotools'})
         if os.path.isfile('autogen.sh'):
             para['override'].update({'autogen'})
         else:
@@ -254,12 +263,14 @@ def analyze(para):
         para['dh_with'].update({'autotools-dev'})
         para['build_type']      = 'Autotools'
         para['build_depends'].update({'autotools-dev'})
+        para['export'].update({'autotools'})
     elif os.path.isfile('configure.in') and \
             os.path.isfile('Makefile.am') and \
             os.path.isfile('configure'):
         para['dh_with'].update({'autotools-dev'})
         para['build_type']      = 'Autotools (old)'
         para['build_depends'].update({'autotools-dev'})
+        para['export'].update({'autotools'})
         print('W: Use of configure.in has been deprecated since 2001.', file=sys.stderr)
     elif 'autoreconf' in para['dh_with']:
         print('E: missing configure.ac or Makefile.am required for "dh $@ --with autoreconf".', file=sys.stderr)
@@ -272,15 +283,17 @@ def analyze(para):
         para['build_type']      = 'configure'
         if setmultiarch:
             para['override'].update({'multiarch'})
-    # GNU coding standard with make
-    elif os.path.isfile('Makefile'):
-        para['build_type']      = 'make'
-        if setmultiarch:
-            para['override'].update({'multiarch'})
     # GNU coding standard with Cmake
     elif os.path.isfile('CMakeLists.txt'):
         para['build_type']      = 'Cmake'
         para['build_depends'].update({'cmake'})
+        para['override'].update({'cmake'})
+        if setmultiarch:
+            para['override'].update({'multiarch'})
+    # GNU coding standard with make
+    elif os.path.isfile('Makefile'):
+        para['build_type']      = 'make'
+        para['override'].update({'makefile'})
         if setmultiarch:
             para['override'].update({'multiarch'})
     # Python distutils
