@@ -33,6 +33,11 @@ import sys
 import debmake.debug
 import debmake.lc
 ###################################################################
+# Constants for sanity
+###################################################################
+MAX_COPYRIGHT_LINES = 256
+MAX_COPYRIGHT_LENGTH = 2048
+###################################################################
 # Parse year within a copyright line
 ###################################################################
 re_year_1900 = re.compile(r'''
@@ -346,6 +351,7 @@ re_dropline = re.compile(r'''(?:
         ^timestamp=|                        # timestamp line
         ^scriptversion=|                    # version line
         ^All\s+Rights\s+Reserved|           # possible leader
+        ^LICENSE:|                          # 
         ^written\s+by|
         ^This\s+file\s+is\s+part\s+of\s+GNU|
         ^Last\s+update:\s|
@@ -384,9 +390,10 @@ re_co = re.compile(r'(?:\\\(co|\(c\)|@copyright\{\})', re.IGNORECASE) # fake mat
 
 # search to allow leading jank words
 re_copyright_line = re.compile(r'''
-        (?:(?:Copyright|Copyr\.)(?:\s*©)?|
-        ©\s*(?:Copyright|Copyr\.)|
-        ©)\s*(?P<copyright>.*)$
+        (?:(?:Copyright|Copyr\.)\s*©\s*|
+        ©\s*(?:Copyright|Copyr\.)\s+|
+        (?:Copyright:?|Copyr\.)\s+|
+        ©\s*)(?P<copyright>[^\s].*)$
         ''', re.IGNORECASE | re.VERBOSE)
 
 def clean_copyright(line):
@@ -432,18 +439,26 @@ re_copyright_mark_maybe = re.compile(r'''
         (?:Copyright|Copyr\.|\(C\)|©|\\\(co) # fake )
         ''', re.IGNORECASE | re.VERBOSE)
 
+# matching line is excluded to be identified as copyright.
 re_copyright_mark_exclude = re.compile(r'''(?:
         [=?$]|                  # C MACRO
-        Copyright\s+holder|     # copyright holders ...
-        copyright\s+and\s+license| # copyright and license
-        Copyright[!-')-~]|      # no coding variables
-        Copyright:?$|           # ... copyright
+        [^h][-+*/_a-su-z0-9]\(C\)|  # C MACRO (but Copyright(C) is not included)
         if\s+\(C\)|             # C code
-        ^modified\s+version|    # ... of Copyright
-        [^h][-+*/_a-su-z0-9]\(C\)|  # C MACRO (but Copyright(C) is OK)
-        (?:def|if|return)\s.*\(C\)| # Python/C
         switch\s+\(C\)|         # C code
-        ^This\s                 # This ...  Copyright
+        (?:def|if|return)\s.*\(C\)| # Python/C
+        /Copyright|             # file name
+        Copyright[^\s(:]|       # text or variable name
+        Copyright:?$|           # text
+        Copyright\s+notice|     # text
+        Copyright\s+holder|     # text
+        Copyright\s+section|    # text
+        Copyright\s+stanza|     # text
+        copyright\s+file|       # text
+        copyright\s+and\s+license| # text
+        of\s+copyright| # text
+        their\s+copyright|    # text
+        the\s+copyright|    # text
+        ^This\s.*copyright      # text
         )''', re.IGNORECASE | re.VERBOSE)
 
 re_copyright_nomark_year = re.compile(r'''
@@ -515,6 +530,7 @@ re_license_end_nostart = re.compile(r'''(
         ^"""|^\'\'\'|                   # python block comment
         ^=cut|                          # perl
         ^---|^@@|                       # diff block
+        ^\.TH|                          # no .TH for manpage
         ^\.SH|                          # no .SH for manpage
         ^Who\sare\swe\?$|               # The Linux Foundation License templates
         ^-----------|                   # ./configure
@@ -524,6 +540,7 @@ re_license_end_nostart = re.compile(r'''(
         ^This\sfile\sis\smaintained|    # Automake files
         ^Do\sall\sthe\swork\sfor\sAutomake| # aclocal.m4 Automake
         ^Originally\s+written\s+by\+.{10,20}?\s+Please\s+send\spatches| # config.guess
+        ^Please\s+note\s+that\s+the| # Makefile.in.in (gettext)
         ^Please\s+send\s+patches\s+with|   # config.sub
         ^Please\s+send\s+patches\s+to|  # config.sub, config.guess
         ^if\s+not\s+1,\s+datestamp\s+to\s+the\s+version\s+number|  # configure.ac
@@ -554,6 +571,8 @@ def check_lines(lines):
     ##########################################################################
     for line in lines:
         line = line.strip()
+        if line == '.': # empty line only with . as empty
+            line = ''
         # set previous values
         xformat_state = format_state
         xcontent_state = content_state
@@ -673,6 +692,19 @@ def check_lines(lines):
         debmake.debug.debug('De: *end* format={}->{}, content={}->{}, copyright={}, license={}: "{}"'.format(fs[xformat_state], fs[format_state], cs[xcontent_state], cs[content_state], copyright_found, license_found, line), type='e')
     ##########################################################################
     # main loop for lines (end)
+    # sanitize copyright_lines
+    ##########################################################################
+    if len(copyright_lines) > MAX_COPYRIGHT_LINES:
+        print('W: !!!!! too many copyright lines !!!!!', file=sys.stderr)
+        print('W: starting with {}'.format(copyright_lines[0]), file=sys.stderr)
+        copyright_lines = copyright_lines[:MAX_COPYRIGHT_LINES]
+    for (i, line) in enumerate(copyright_lines):
+        if len(line) > MAX_COPYRIGHT_LENGTH:
+            copyright_lines[i] = line[:MAX_COPYRIGHT_LENGTH]
+            print('W: !!!!! too long copyright line !!!!!', file=sys.stderr)
+            print('W: starting with {}'.format(copyright_lines[i]), file=sys.stderr)
+    ##########################################################################
+    # analyze copyright
     ##########################################################################
     copyright_data = analyze_copyright(copyright_lines)
     license_lines = clean_license(license_lines)
@@ -681,10 +713,10 @@ def check_lines(lines):
         debmake.debug.debug('Da: {}'.format(line), type='a')
     if copyright_data == {} and license_lines == []:
         # no copyright and no license
-        copyright_data = {'__NO_COPYRIGHT_NOR_LICENSE__':(0, 0)}
+        copyright_data = {'__NO_COPYRIGHT_NOR_LICENSE__':(9999, 0)}
     elif copyright_data == {}:
         # no copyright and but with license (Maybe __UNKNOWN__ license)
-        copyright_data = {'__NO_COPYRIGHT__':(0, 0)}
+        copyright_data = {'__NO_COPYRIGHT__':(9999, 0)}
     return (copyright_data, license_lines)
 
 ###################################################################
@@ -707,6 +739,35 @@ def check_license(file, encoding='utf-8'):
             (copyright_data, license_lines) = check_lines(fd.readlines())
     return (copyright_data, license_lines)
 
+###################################################################
+# Check autogenerated files
+###################################################################
+re_autofiles = re.compile(r'''(
+        ^Makefile.in$| # Autotools
+        ^.*/Makefile\.in$| # Autotools
+        ^aclocal.m4$| # Autotools
+        ^build-aux/.*$| # Autotools
+        ^compile$| # Autotools
+        ^config\.guess$| # Autotools
+        ^config\.status$| # Autotools
+        ^config\.sub$| # Autotools
+        ^config\.rpath$| # Autotools
+        ^configure$| # Autotools
+        ^depcomp$| # Autotools
+        ^install-sh$| # Autotools
+        ^libltdl/.*$| # Autotools
+        ^libtool$| # Autotools
+        ^ltmain.sh$| # Autotools
+        ^missing$| # Autotools
+        ^py-compile$| # Autotools
+        ^test-driver$| # Autotools
+        ^po/Makefile$| # Autotools (getttext)
+        ^po/Makefile\.in$| # Autotools (gettext)
+        ^po/Makefile\.in\.in$| # Autotools (gettext)
+        ^po/Makevars$| # Autotools (gettext)
+        ^m4/.*$        # Autotools (no | at the end)
+        )''', re.IGNORECASE | re.VERBOSE)
+
 ###################################################################
 # Check all appearing copyright and license texts
 ###################################################################
@@ -715,9 +776,14 @@ def check_license(file, encoding='utf-8'):
 # data[*][2]: copyright holder info (data=dictionary): copyright_lines
 # data[*][3]: license text (original: list of lines): license_lines
 ###################################################################
-def check_all_licenses(files, encoding='utf-8', mode=0):
+def check_all_licenses(files, encoding='utf-8', mode=0, pedantic=False):
     adata = []
     license_cache = {} # hashtable for quicker license scan
+    md5hash = hashlib.md5()
+    licensetext0 = '\n Auto-generated file under the permissive license.'
+    md5hash.update(licensetext0.encode())
+    md5hashkey0 = md5hash.hexdigest()
+    license_cache[md5hashkey0] = ('__AUTO_PERMISSIVE__', licensetext0, True)
     if len(files) == 0:
         print('W: check_all_licenses(files) should have files', file=sys.stderr)
     if sys.hexversion >= 0x03030000: # Python 3.3 ...
@@ -728,20 +794,28 @@ def check_all_licenses(files, encoding='utf-8', mode=0):
             if sys.hexversion >= 0x03030000: # Python 3.3 ...
                 print('.', file=sys.stderr, end='', flush=True)
             (copyright_data, license_lines) = check_license(file, encoding=encoding)
+            debmake.debug.debug('Dc: copyright_data  = {}'.format(copyright_data), type='c')
             norm_text = debmake.lc.normalize(license_lines)
             md5hash = hashlib.md5()
             md5hash.update(norm_text.encode())
             md5hashkey = md5hash.hexdigest()
             if md5hashkey in license_cache.keys():
-                (licenseid, licensetext) = license_cache[md5hashkey]
+                (licenseid, licensetext, permissive) = license_cache[md5hashkey]
             else:
-                (licenseid, licensetext) = debmake.lc.lc(norm_text, license_lines, mode)
-                license_cache[md5hashkey] = (licenseid, licensetext)
+                (licenseid, licensetext, permissive) = debmake.lc.lc(norm_text, license_lines, mode)
+                license_cache[md5hashkey] = (licenseid, licensetext, permissive)
+            if not pedantic and permissive and re_autofiles.search(file):
+                debmake.debug.debug('Dl: LICENSE ID = __AUTO_PERMISSIVE__ from {}'.format(licenseid), type='l')
+                licenseid = '__AUTO_PERMISSIVE__'
+                licensetext = licensetext0
+                md5hashkey = md5hashkey0
+            else:
+                debmake.debug.debug('Dl: LICENSE ID = {}'.format(licenseid), type='l')
             adata.append((md5hashkey, copyright_data, licenseid, licensetext, file))
         else:
             print('W: check_all_licenses on non-existing file: {}'.format(file), file=sys.stderr)
         for c in copyright_data.keys():
-            debmake.debug.debug('Dc: {}-{}: {}'.format(copyright_data[c][0], copyright_data[c][0], c), type='c')
+            debmake.debug.debug('Dc: {}-{}: {}'.format(copyright_data[c][0], copyright_data[c][1], c), type='c')
         for l in license_lines:
             debmake.debug.debug('Dl: {}'.format(l), type='l')
     print('\nI: check_all_licenses completed for {} files.'.format(len(files)), file=sys.stderr)
@@ -769,7 +843,7 @@ def bunch_all_licenses(adata):
         sortkey = '{0:03} {1:02} {2} {3}'.format(max(0, 1000 - len(bunched_files)), min(99, len(licenseid)), licenseid, md5hashkey)
         bunched_files = sorted(bunched_files)
         copyright_list = []
-        for name, (year_min, year_max) in copyright_data.items():
+        for name, (year_min, year_max) in bunched_copyright_data.items():
             copyright_list.append((year_min, year_max, name))
         copyright_list = sorted(copyright_list)
         bdata.append((sortkey, bunched_files, copyright_list, licenseid, licensetext))
@@ -797,9 +871,9 @@ def format_all_licenses(bdata):
             cdata.append((licenseid, licensetext, bunched_files, copyright_lines))
     return cdata
 
-def check_copyright(files, mode=0, encoding='utf-8'):
+def check_copyright(files, mode=0, encoding='utf-8', pedantic=False):
     print('I: check_all_licenses', file=sys.stderr)
-    adata = check_all_licenses(files, encoding=encoding, mode=mode)
+    adata = check_all_licenses(files, encoding=encoding, mode=mode, pedantic=pedantic)
     print('I: bunch_all_licenses', file=sys.stderr)
     bdata = bunch_all_licenses(adata)
     print('I: format_all_licenses', file=sys.stderr)
@@ -842,7 +916,7 @@ def license_text(file, encoding='utf-8'):
 #######################################################################
 # main program
 #######################################################################
-def copyright(package_name, license_file_masks, data, xml_html_files, binary_files, huge_files, mode=0):
+def copyright(package_name, license_file_masks, data, xml_html_files, binary_files, huge_files, mode=0, tutorial=False):
     # mode: 0: not -c, 1: -c simple, 2: -cc normal, 3: -ccc extensive
     #      -1: -cccc debug simple, -2 -ccccc debug normal -3 -cccccc debug extensive
     # make text to print
@@ -850,7 +924,9 @@ def copyright(package_name, license_file_masks, data, xml_html_files, binary_fil
 Format: http://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
 Upstream-Name: {}
 Source: <url://example.com>
-###
+'''.format(package_name)
+    if tutorial:
+        text += '''###
 ### Uncomment the following 2 lines to enable uscan to exclude non-DFSG components 
 ### Files-Excluded: command/non-dfsg.exe
 ###   docs/source/javascripts/jquery-1.7.1.min.js
@@ -866,7 +942,9 @@ Source: <url://example.com>
 ### Please avoid to pick license terms that are more restrictive than the
 ### packaged work, as it may make Debian's contributions unacceptable upstream.
 
-'''.format(package_name)
+'''
+    else:
+        text += '\n'
     for (licenseid, licensetext, files, copyright_lines) in data:
         # Files:
         text +=             'Files:     {}\n'.format('\n           '.join(files))
